@@ -34,6 +34,8 @@ __license__ = "MIT"
 
 _logger = logging.getLogger(__name__)
 
+package = __name__.split(".")[0]
+
 
 # ---- Python API ----
 # The functions defined in this section can be imported by users in their
@@ -81,6 +83,15 @@ def parse_args(args):
         action="store_const",
         const=logging.DEBUG,
     )
+    parser.add_argument(
+        "-d",
+        "--delay-to-prevent-crash",
+        type=float,
+        default=0.5,
+        required=False,
+        metavar="FLOAT",
+        help="delay fetches to prevent sls crash",
+    )
     parser.add_argument(
         "-c",
         "--session-count",
@@ -93,10 +104,10 @@ def parse_args(args):
     parser.add_argument(
         "-l",
         "--session-lifetime-hours",
-        type=int,
-        default=1,
+        type=float,
+        default=0.5,
         required=False,
-        metavar="INT",
+        metavar="FLOAT",
         help="session lifetime in hours",
     )
 
@@ -109,9 +120,14 @@ def setup_logging(loglevel):
     Args:
       loglevel (int): minimum loglevel for emitting messages
     """
-    logformat = "[%(asctime)s] %(levelname)s:%(name)s:%(message)s"
+    logformat = "{%(filename)s:%(lineno)d} %(levelname)s - %(message)s"
     logging.basicConfig(
-        level=loglevel, stream=sys.stdout, format=logformat, datefmt="%Y-%m-%d %H:%M:%S"
+        level=loglevel,
+        format=logformat,
+        handlers=[
+            # logging.FileHandler(f"{package}.log"),
+            logging.StreamHandler(sys.stdout),
+        ],
     )
 
 
